==> apache-eventmesh-1.9.0-source.tar.gz: apache-eventmesh-1.9.0-src/eventmesh-common/src/main/java/org/apache/eventmesh/common/protocol/http/header/message/SendMessageResponseHeader.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.eventmesh.common.protocol.http.header.message;


import org.apache.eventmesh.common.protocol.http.common.ProtocolKey;
import org.apache.eventmesh.common.protocol.http.header.Header;

import java.util.HashMap;
import java.util.Map;

public class SendMessageResponseHeader extends Header {

    //response code, as same as the request code
    private int code;

    //The cluster name of the EventMesh that processes the request
    private String eventMeshCluster;

    //IP of the EventMesh that processes the request
    private String eventMeshIp;

    //Environment number of the EventMesh that processes the request
    private String eventMeshEnv;

    //IDC of the EventMesh that processes the request
    private String eventMeshIdc;

    public int getCode() {
        return code;
    }

    public void setCode(int code) {
        this.code = code;
    }

    public String getEventMeshCluster() {
        return eventMeshCluster;
    }

    public void setEventMeshCluster(String eventMeshCluster) {
        this.eventMeshCluster = eventMeshCluster;
    }

    public String getEventMeshIp() {
        return eventMeshIp;
    }

    public void setEventMeshIp(String eventMeshIp) {
        this.eventMeshIp = eventMeshIp;
    }

    public String getEventMeshEnv() {
        return eventMeshEnv;
    }

    public void setEventMeshEnv(String eventMeshEnv) {
        this.eventMeshEnv = eventMeshEnv;
    }

    public String getEventMeshIdc() {
        return eventMeshIdc;
    }

    public void setEventMeshIdc(String eventMeshIdc) {
        this.eventMeshIdc = eventMeshIdc;
    }

    public static SendMessageResponseHeader buildHeader(Integer requestCode, String eventMeshCluster,
        String eventMeshIp, String eventMeshEnv,
        String eventMeshIDC) {
        SendMessageResponseHeader sendMessageResponseHeader = new SendMessageResponseHeader();
        sendMessageResponseHeader.setCode(requestCode);
        sendMessageResponseHeader.setEventMeshCluster(eventMeshCluster);
        sendMessageResponseHeader.setEventMeshIp(eventMeshIp);
        sendMessageResponseHeader.setEventMeshEnv(eventMeshEnv);
        sendMessageResponseHeader.setEventMeshIdc(eventMeshIDC);
        return sendMessageResponseHeader;
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("sendMessageResponseHeader={")
            .append("code=").append(code).append(",")
            .append("eventMeshEnv=").append(eventMeshEnv).append(",")
            .append("eventMeshIdc=").append(eventMeshIdc).append(",")
            .append("eventMeshCluster=").append(eventMeshCluster).append(",")
            .append("eventMeshIp=").append(eventMeshIp).append("}");
        return sb.toString();
    }

    @Override
    public Map<String, Object> toMap() {
        Map<String, Object> map = new HashMap<String, Object>();
        map.put(ProtocolKey.REQUEST_CODE, code);
        map.put(ProtocolKey.EventMeshInstanceKey.EVENTMESHCLUSTER, eventMeshCluster);
        map.put(ProtocolKey.EventMeshInstanceKey.EVENTMESHIP, eventMeshIp);
        map.put(ProtocolKey.EventMeshInstanceKey.EVENTMESHENV, eventMeshEnv);
        map.put(ProtocolKey.EventMeshInstanceKey.EVENTMESHIDC, eventMeshIdc);
        return map;
    }
}

==> apache-eventmesh-1.11.0-source.tar.gz: apache-eventmesh-1.11.0-src/eventmesh-common/src/main/java/org/apache/eventmesh/common/protocol/http/header/message/SendMessageResponseHeader.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.eventmesh.common.protocol.http.header.message;

import org.apache.eventmesh.common.protocol.http.common.ProtocolKey;
import org.apache.eventmesh.common.protocol.http.header.Header;
import org.apache.eventmesh.common.utils.HttpConvertsUtils;

import java.util.Map;

import lombok.Getter;
import lombok.Setter;
import lombok.ToString;

@Setter
@Getter
@ToString
public class SendMessageResponseHeader extends Header {

    // response code, as same as the request code
    private int code;

    // The cluster name of the EventMesh that processes the request
    private String eventMeshCluster;

    // IP of the EventMesh that processes the request
    private String eventMeshIp;

    // Environment number of the EventMesh that processes the request
    private String eventMeshEnv;

    // IDC of the EventMesh that processes the request
    private String eventMeshIdc;

    public static SendMessageResponseHeader buildHeader(Integer requestCode, String eventMeshCluster,
        String eventMeshIp, String eventMeshEnv,
        String eventMeshIDC) {
        SendMessageResponseHeader sendMessageResponseHeader = new SendMessageResponseHeader();
        sendMessageResponseHeader.setCode(requestCode);
        sendMessageResponseHeader.setEventMeshCluster(eventMeshCluster);
        sendMessageResponseHeader.setEventMeshIp(eventMeshIp);
        sendMessageResponseHeader.setEventMeshEnv(eventMeshEnv);
        sendMessageResponseHeader.setEventMeshIdc(eventMeshIDC);
        return sendMessageResponseHeader;
    }

    @Override
    public Map<String, Object> toMap() {
        HttpConvertsUtils httpConvertsUtils = new HttpConvertsUtils();
        ProtocolKey protocolKey = new ProtocolKey();
        ProtocolKey.EventMeshInstanceKey eventMeshInstanceKey = new ProtocolKey.EventMeshInstanceKey();
        return httpConvertsUtils.httpMapConverts(this, protocolKey, eventMeshInstanceKey);
    }
}
